# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('newsletter', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='CloudMailInformation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('messageId', models.TextField(max_length=2048)),
                ('message', models.TextField(default=b'')),
                ('contact', models.ForeignKey(to='newsletter.Contact')),
                ('newsletter', models.ForeignKey(to='newsletter.Newsletter')),
            ],
        ),
        migrations.CreateModel(
            name='NewsletterInformation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('sync', models.BooleanField(default=True)),
                ('newsletter', models.ForeignKey(to='newsletter.Newsletter', unique=True)),
            ],
        ),
    ]
